/*
 * ListMenuDisplayer.java
 *
 * Created on December 7, 2002, 12:35 AM
 */
package net.sf.navigator.displayer;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;

import net.sf.navigator.menu.MenuComponent;

import org.apache.commons.lang.StringUtils;


/**
 *
 * @author  <a href="mailto:matt@raibledesigns.com">Matt Raible</a>
 * @version 1.0
 */
public class ListMenuDisplayer extends MessageResourcesMenuDisplayer {
    //~ Instance fields ========================================================

    //~ Methods ================================================================

    public void init(PageContext pageContext, MenuDisplayerMapping mapping) {
        super.init(pageContext, mapping);

        try {
            out.println(displayStrings.getMessage("lmd.begin"));
        } catch (Exception e) {}
    }

    public void display(MenuComponent menu) throws JspException, IOException {
        if (isAllowed(menu)) {
            out.println(displayStrings.getMessage("lmd.menu.top"));
            displayComponents(menu, 0);
            out.println(displayStrings.getMessage("lmd.menu.bottom"));
        }
    }

    protected void displayComponents(MenuComponent menu, int level)
    throws JspException, IOException {
        String title = super.getMessage(menu.getTitle());
        MenuComponent[] components = menu.getMenuComponents();

        if (components.length > 0) {
            // eliminate spaces in string used for Id
            String domId =
                StringUtils.deleteWhitespace(getMessage(menu.getTitle()));

            String menuClass = "menu";

            if (level >= 1) {
                menuClass = "submenu";
            }

            // if there is a location/page/action tag on base item use it
            if (menu.getUrl() != null ){
                out.println(displayStrings.getMessage("lmd.menu.actuator.link",
                            domId, getMessage(menu.getTitle()), menuClass,
                            getMessage(menu.getUrl())));
            } else {
                out.println(displayStrings.getMessage("lmd.menu.actuator.top",
                        domId,
                        getMessage(menu.getTitle()),
                        menuClass));
            }
            
            for (int i = 0; i < components.length; i++) {
                // check the permissions on this component
                if (isAllowed(components[i])) {
                    if (components[i].getMenuComponents().length > 0) {
                        out.println("<li>");

                        displayComponents(components[i], level + 1);

                        out.println(displayStrings.getMessage("lmd.menu.actuator.bottom"));

                        if (i == (components[i].getMenuComponents().length - 1)) { // last one
                            out.println("</li>");
                        }
                    } else {
                        out.println(displayStrings.getMessage("lmd.menu.item",
                                                              components[i].getUrl(),
                                                              super.getMenuToolTip(components[i]),
                                                              getExtra(components[i]),
                                                              this.getMessage(components[i].getTitle())));
                    }
                }
            }

            // close the </ul> for the top menu
            if (menuClass.equals("menu")) {
                out.println("</ul>");
            }
        } else {
            if (menu.getParent() == null) {
                out.println(displayStrings.getMessage("lmd.menu.standalone",
                                                      menu.getUrl(),
                                                      super.getMenuToolTip(menu),
                                                      getExtra(menu),
                                                      getMessage(menu.getTitle())));
            } else {
                out.println(displayStrings.getMessage("lmd.menu.item",
                                                      menu.getUrl(),
                                                      super.getMenuToolTip(menu),
                                                      getExtra(menu),
                                                      getMessage(menu.getTitle())));
            }
        }
    }

    /**
     * This will output the ending HTML code to close tags from the beginning
     * @param context the current pageContext
     */
    public void end(PageContext context) {
        try {
            out.print(displayStrings.getMessage("lmd.end"));
        } catch (Exception e) {}
    }

    public String getExtra(MenuComponent menu) {
        StringBuffer extra = new StringBuffer();
        if (menu.getTarget() != null) {
            extra.append(" target=\"" + menu.getTarget() + "\"");
        }
        if (menu.getOnclick() != null) {
            extra.append(" onclick=\"" + menu.getOnclick() + "\"");
        }
        return (extra.length() > 0) ? extra.toString() : "";
    }
}
