package net.sf.navigator.taglib.el;

import java.net.MalformedURLException;

import javax.servlet.jsp.JspException;

import net.sf.navigator.menu.MenuComponent;


/**
 * This tag acts the same as net.sf.navigator.taglib.DisplayMenuTag, except
 * that it allows JSTL Expressions in it's name and target attributes.
 *
 * @author Matt Raible
 * @version $Revision: 1.4 $ $Date: 2004/09/22 08:21:35 $
 */
public class DisplayMenuTag extends net.sf.navigator.taglib.DisplayMenuTag {
    /** Holds value of property name. */
    private String _name;

    /** Holds value of property target. */
    private String _target;

    /** Setter for property name.
     * @param name New value of property name.
     */
    public void setName(String name) {
        this._name = name;
    }

    /** Setter for property target.
     * @param target New value of property target.
     */
    public void setTarget(String target) {
        this._target = target;
    }

    public DisplayMenuTag() {
        super();
        init();
    }

    private void init() {
        _name = null;
        _target = null;
    }

    public void release() {
        super.release();
        init();
    }

    public int doStartTag() throws JspException {
        evaluateExpressions();

        return super.doStartTag();
    }

    /**
     * Overrides the setPageLocation in parentTag to use JSTL to evaluate
     * the URL.  It's definitely ugly, so if you have a cleaner way, please
     * let me know!
     *
     * @param menu
     */
    protected void setPageLocation(MenuComponent menu)
    throws MalformedURLException, JspException {
    	setLocation(menu);
        String url = menu.getLocation();

        // Use JSTL to replace dynamic values in the URL
        ExpressionEvaluator eval = new ExpressionEvaluator(this, pageContext);

        String s;

        if ((s = eval.evalString("url", url)) != null) {
            menu.setUrl(s);
        }

        // do all contained menus
        MenuComponent[] subMenus = menu.getMenuComponents();

        if (subMenus.length > 0) {
            for (int i = 0; i < subMenus.length; i++) {
                setPageLocation(subMenus[i]);
            }
        }
    }

    private void evaluateExpressions() throws JspException {
        ExpressionEvaluator eval = new ExpressionEvaluator(this, pageContext);
        String s;

        if ((s = eval.evalString("name", _name)) != null) {
            super.setName(s);
        }

        if ((s = eval.evalString("target", _target)) != null) {
            super.setTarget(s);
        }
    }
}
